@@ -1,11 +1,21 @@
 package Test::Routine::Runner;
 {
-  $Test::Routine::Runner::VERSION = '0.017';
+  $Test::Routine::Runner::VERSION = '0.018';
 }
 use Moose;
 # ABSTRACT: tools for running Test::Routine tests
 
 
+
+
+
+
+
+
+
+
+
+
 use Carp qw(confess croak);
 use Scalar::Util qw(reftype);
 use Test::More ();
@@ -84,7 +94,8 @@ sub run {
   my @tests = grep { Moose::Util::does_role($_, 'Test::Routine::Test::Role') }
               $thing->meta->get_all_methods;
 
-  if (length(my $re = $ENV{TEST_METHOD})) {
+  my $re = $ENV{TEST_METHOD};
+  if (defined $re and length $re) {
     my $filter = try { qr/$re/ } # compile the the regex separately ...
         catch { croak("TEST_METHOD ($re) is not a valid regular expression: $_") };
     $filter = qr/\A$filter\z/;  # ... so it can't mess with the anchoring
@@ -120,7 +131,7 @@ Test::Routine::Runner - tools for running Test::Routine tests
 
 =head1 VERSION
 
-version 0.017
+version 0.018
 
 =head1 OVERVIEW
 
